@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 from __future__ import print_function
 
-VERSION = '0.4.13'
+VERSION = '0.4.14'
 
 import os
 import sys
@@ -306,7 +306,10 @@ class Kernel(object):
     def patch(self, patch_script):
         os.chdir('{0}/sources/linux-{1}'.format(self.build_dir, self.version))
         self.log('Applying patch: {0}'.format(patch_script))
-        subprocess.call([patch_script])
+        resp = subprocess.call([patch_script])
+        if resp != 0:
+            raise EnvironmentError('Command failed: {0}'.format(patch_script))
+
 
     @require_attr('version')
     @require_attr('revision')
@@ -370,23 +373,24 @@ class Kernel(object):
         )
 
     @require_attr('version')
-    def make(self, jobs=None, background=True):
+    def make(self, jobs=None):
         os.chdir('{0}/sources/linux-{1}'.format(self.build_dir, self.version))
-        if background:
-            stdout = devnull()
-        else:
-            stdout = None
+        cap = len(open('.config').readlines())
         if jobs is None:
             jobs = str(multiprocessing.cpu_count())
         self.log('Making the kernel')
         make_process = subprocess.Popen(
             ['make', '-j' + jobs],
-            stdout=stdout,
-            stderr=stdout,
+            stdout=subprocess.PIPE,
+            stderr=subprocess.PIPE,
         )
-        while make_process.poll() is None:
+        counter = 0
+        while len(make_process.stdout.readline()):
             if self.verbose:
-                progress_bar(random.randint(1, 99), 100)
+                counter += 1
+                progress_bar(counter, cap)
+            time.sleep(1)
+        while make_process.poll() is None:
             time.sleep(1)
         if make_process.returncode != 0:
             print('Failed to make kernel')
